#
# spec file for package qt6-connectivity
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define real_version 6.8.1
%define short_version 6.8
%define tar_name qtconnectivity-everywhere-src
%define tar_suffix %{nil}
#
%global qt6_flavor %{nil}
%if "%{qt6_flavor}" == "docs"
%define pkg_suffix -docs
%endif
#
Name:           qt6-connectivity%{?pkg_suffix}
Version:        6.8.1
Release:        1.0.2.1.sr20241202
Summary:        Qt 6 connectivity tools and libraries
License:        LGPL-3.0-only OR (GPL-2.0-only OR GPL-3.0-or-later)
URL:            https://www.qt.io
Source0:        https://download.qt.io/official_releases/qt/%{short_version}/%{real_version}%{tar_suffix}/submodules/%{tar_name}-%{real_version}%{tar_suffix}.tar.xz
Source99:       qt6-connectivity-rpmlintrc
BuildRequires:  pkgconfig
BuildRequires:  qt6-core-private-devel
BuildRequires:  qt6-network-private-devel
BuildRequires:  cmake(Qt6Core) = %{real_version}
BuildRequires:  cmake(Qt6DBus) = %{real_version}
BuildRequires:  cmake(Qt6Gui) = %{real_version}
BuildRequires:  cmake(Qt6Network) = %{real_version}
BuildRequires:  cmake(Qt6Quick) = %{real_version}
BuildRequires:  cmake(Qt6QuickControls2) = %{real_version}
BuildRequires:  cmake(Qt6Widgets) = %{real_version}
BuildRequires:  pkgconfig(bluez)
BuildRequires:  pkgconfig(libpcsclite)
%if "%{qt6_flavor}" == "docs"
BuildRequires:  qt6-tools
%{qt6_doc_packages}
%endif

%description
Qt 6 connectivity tools and libraries.

%if !%{qt6_docs_flavor}

%package -n libQt6Bluetooth6
Summary:        Qt 6 bluetooth library

%description -n libQt6Bluetooth6
Provides access to Bluetooth hardware.

%package -n libQt6Nfc6
Summary:        Qt 6 NFC library

%description -n libQt6Nfc6
Provides access to NFC hardware.

%package devel
Summary:        Qt 6 connectivity libraries - Development files
Requires:       libQt6Bluetooth6 = %{version}
Requires:       libQt6Nfc6 = %{version}
# sdoscanner in required by Qt6BluetoothToolsTargets.cmake
Requires:       qt6-connectivity = %{version}
Requires:       cmake(Qt6DBus) = %{real_version}
Requires:       cmake(Qt6Network) = %{real_version}

%description devel
Development files for the Qt6 connectivity libraries.

%package private-devel
Summary:        Non-ABI stable API for the Qt 6 connectivity libraries
Requires:       cmake(Qt6Bluetooth) = %{real_version}
Requires:       cmake(Qt6Nfc) = %{real_version}
%requires_eq    qt6-core-private-devel
%requires_eq    qt6-network-private-devel

%description private-devel
This package provides private headers of qt6-connectivity that are normally
not used by application development and that do not have any ABI or
API guarantees.
The packages that build against these have to require the exact Qt version.

%{qt6_examples_package}

%endif

%prep
%autosetup -p1 -n %{tar_name}-%{real_version}%{tar_suffix}

%build
%cmake_qt6 \
  -DQT_GENERATE_SBOM:BOOL=FALSE

%{qt6_build}

%install
%{qt6_install}

%if !%{qt6_docs_flavor}

%ldconfig_scriptlets -n libQt6Bluetooth6
%ldconfig_scriptlets -n libQt6Nfc6

%files
%{_qt6_libexecdir}/sdpscanner

%files -n libQt6Bluetooth6
%license LICENSES/*
%{_qt6_libdir}/libQt6Bluetooth.so.*

%files -n libQt6Nfc6
%license LICENSES/*
%{_qt6_libdir}/libQt6Nfc.so.*

%files devel
%{_qt6_cmakedir}/Qt6/FindBlueZ.cmake
%{_qt6_cmakedir}/Qt6/FindPCSCLITE.cmake
%{_qt6_cmakedir}/Qt6Bluetooth/
%{_qt6_cmakedir}/Qt6BuildInternals/StandaloneTests/QtConnectivityTestsConfig.cmake
%{_qt6_cmakedir}/Qt6Nfc/
%{_qt6_descriptionsdir}/Bluetooth.json
%{_qt6_descriptionsdir}/Nfc.json
%{_qt6_includedir}/QtBluetooth/
%{_qt6_includedir}/QtNfc/
%{_qt6_libdir}/libQt6Bluetooth.prl
%{_qt6_libdir}/libQt6Bluetooth.so
%{_qt6_libdir}/libQt6Nfc.prl
%{_qt6_libdir}/libQt6Nfc.so
%{_qt6_metatypesdir}/qt6bluetooth*_metatypes.json
%{_qt6_metatypesdir}/qt6nfc_*_metatypes.json
%{_qt6_mkspecsdir}/modules/qt_lib_bluetooth.pri
%{_qt6_mkspecsdir}/modules/qt_lib_nfc.pri
%{_qt6_pkgconfigdir}/Qt6Bluetooth.pc
%{_qt6_pkgconfigdir}/Qt6Nfc.pc
%exclude %{_qt6_includedir}/QtBluetooth/%{real_version}/
%exclude %{_qt6_includedir}/QtNfc/%{real_version}/

%files private-devel
%dir %{_qt6_includedir}/QtBluetooth
%dir %{_qt6_includedir}/QtNfc
%{_qt6_includedir}/QtBluetooth/%{real_version}/
%{_qt6_includedir}/QtNfc/%{real_version}/
%{_qt6_mkspecsdir}/modules/qt_lib_bluetooth_private.pri
%{_qt6_mkspecsdir}/modules/qt_lib_nfc_private.pri

%endif

%changelog
* Mon Dec  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.8.1:
  * https://www.qt.io/blog/qt-6.8.1-released
* Tue Oct  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.8.0:
  * https://www.qt.io/blog/qt-6.8-released
* Sat Sep 28 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.7.3
  * https://www.qt.io/blog/qt-6.7.3-released
* Wed Jun 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.7.2:
  * https://www.qt.io/blog/qt-6.7.2-released
* Tue May 21 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.7.1:
  * https://www.qt.io/blog/qt-6.7.1-released
* Tue Apr  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.7.0:
  * https://www.qt.io/blog/qt-6.7-released
* Tue Mar 26 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.6.3:
  * https://www.qt.io/blog/qt-6.6.3-released
* Wed Feb 14 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.6.2
  * https://www.qt.io/blog/qt-6.6.2-released
* Mon Nov 27 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.6.1:
  * https://www.qt.io/blog/qt-6.6.1-released
* Tue Oct 10 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.6.0
  * https://www.qt.io/blog/qt-6.6-released
* Thu Sep 28 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.5.3
  * https://www.qt.io/blog/qt-6.5.3-released
* Thu Jul 20 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.5.2
  * https://www.qt.io/blog/qt-6.5.2-released-1
* Fri Jun 30 2023 Christophe Marin <christophe@krop.fr>
- Update subpackages requirements
* Wed May 24 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.5.1
  * https://www.qt.io/blog/qt-6.5.1-released
* Mon Apr  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.5.0
  * https://www.qt.io/blog/qt-6.5-lts-released
* Thu Mar 16 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.4.3:
  * https://www.qt.io/blog/qt-6.4.3-released
* Fri Jan  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.4.2:
  * https://www.qt.io/blog/qt-6.4.2-released
* Tue Nov 15 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.4.1:
  * https://www.qt.io/blog/qt-6.4.1-released
* Thu Sep 29 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.4.0:
  * https://www.qt.io/blog/qt-6.4-released
* Fri Sep 16 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.4.0 RC
* Fri Sep  9 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.3.2:
  * https://www.qt.io/blog/qt-6.3.2-released
* Fri Jun 17 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.3.1:
  * https://www.qt.io/blog/qt-6.3.1-released
* Fri Apr  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.3.0:
  * https://www.qt.io/blog/qt-6.3-released
* Tue Mar 29 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.3.0-rc
* Mon Mar 21 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.4
  * https://www.qt.io/blog/qt-6.2.4-released
* Mon Jan 31 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.3:
  * https://www.qt.io/blog/qt-6.2.3-released
* Wed Dec  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.2
  * https://www.qt.io/blog/qt-6.2.2-released
- Make sure all dependencies are present when installing devel
  packages. Qt >= 6.2.2 is much less permissive.
* Tue Oct 26 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.1
  * https://www.qt.io/blog/qt-6.2.1-released
* Thu Sep 30 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.0:
  * https://www.qt.io/blog/qt-6.2-lts-released
* Sat Sep 25 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.0-rc2
* Thu Sep 16 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.0-rc
* Thu Sep  9 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.0-beta4
* Sat Feb  1 2020 Christophe Giboudeaux <christophe@krop.fr>
- Add qt6-connectivity
